==> vaadin-sass-compiler-0.9.0.jar: com/vaadin/sass/internal/tree/NestPropertiesNode.java <==
/*
 * Copyright 2000-2014 Vaadin Ltd.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package com.vaadin.sass.internal.tree;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import com.vaadin.sass.internal.visitor.NestedNodeHandler;

public class NestPropertiesNode extends Node implements IVariableNode {
    private static final long serialVersionUID = 3671253315690598308L;

    public NestPropertiesNode(String name) {
        super();
        this.name = name;
    }

    private String name;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    @Override
    public String toString() {
        return "Nest properties node [ name = " + name + " ]";
    }

    public Collection<RuleNode> unNesting() {
        List<RuleNode> result = new ArrayList<RuleNode>();
        for (Node child : children) {
            RuleNode createNewRuleNodeFromChild = createNewRuleNodeFromChild((RuleNode) child);
            result.add(createNewRuleNodeFromChild);
        }
        return result;
    }

    public RuleNode createNewRuleNodeFromChild(RuleNode child) {
        StringBuilder builder = new StringBuilder(name);
        builder.append("-").append(child.getVariable());
        RuleNode newRuleNode = new RuleNode(builder.toString(),
                child.getValue(), child.isImportant(), null);
        return newRuleNode;
    }

    @Override
    public void replaceVariables(ArrayList<VariableNode> variables) {
        for (Node child : getChildren()) {
            if (child instanceof RuleNode) {
                ((RuleNode) child).replaceVariables(variables);
            }
        }
    }

    @Override
    public void traverse() {
        NestedNodeHandler.traverse(this);
    }

    @Override
    public String printState() {
        return null;
    }

}

==> vaadin-sass-compiler-0.9.3.jar: com/vaadin/sass/internal/tree/NestPropertiesNode.java <==
/*
 * Copyright 2000-2014 Vaadin Ltd.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package com.vaadin.sass.internal.tree;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import com.vaadin.sass.internal.visitor.NestedNodeHandler;

public class NestPropertiesNode extends Node implements IVariableNode {
    private static final long serialVersionUID = 3671253315690598308L;

    public NestPropertiesNode(String name) {
        super();
        this.name = name;
    }

    private String name;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    @Override
    public String toString() {
        return "Nest properties node [ name = " + name + " ]";
    }

    public Collection<RuleNode> unNesting() {
        List<RuleNode> result = new ArrayList<RuleNode>();
        for (Node child : children) {
            RuleNode createNewRuleNodeFromChild = createNewRuleNodeFromChild((RuleNode) child);
            result.add(createNewRuleNodeFromChild);
        }
        return result;
    }

    public RuleNode createNewRuleNodeFromChild(RuleNode child) {
        StringBuilder builder = new StringBuilder(name);
        builder.append("-").append(child.getVariable());
        RuleNode newRuleNode = new RuleNode(builder.toString(),
                child.getValue(), child.isImportant(), null);
        return newRuleNode;
    }

    @Override
    public void replaceVariables(Collection<VariableNode> variables) {
        for (Node child : getChildren()) {
            if (child instanceof RuleNode) {
                ((RuleNode) child).replaceVariables(variables);
            }
        }
    }

    @Override
    public void traverse() {
        NestedNodeHandler.traverse(this);
    }

    @Override
    public String printState() {
        return null;
    }

}
